@@ -15,8 +15,8 @@ BFDP <- function(a,b,pi1,W,logscale=FALSE)
   z <- thetahat / sqrt(V)
   ABF <- exp(-r*z^2/2) / sqrt(1-r)
   ABFDP <- ABF*PO/(ABF*PO+1)
-  pH0 <- dnorm(thetahat,m=0,s=sqrt(V))
-  pH1 <- dnorm(thetahat,m=0,s=sqrt(postvar))
+  pH0 <- dnorm(thetahat,mean=0,sd=sqrt(V))
+  pH1 <- dnorm(thetahat,mean=0,sd=sqrt(postvar))
   BF <- pH0/pH1
   BFDP <- BF*PO/(BF*PO+1)
   invisible(list(pH0=pH0,pH1=pH1,BF=BF,BFDP=BFDP,ABF=ABF,ABFDP=ABFDP))
