@@ -521,7 +521,11 @@ ReadGRMPCA <- function(prefix)
 invnormal <- function(x)
   qnorm((rank(x,na.last="keep")-0.5)/sum(!is.na(x))) 
 
-# log10(p) for a standard normal deviate z based on log()
+# log(p) for a normal deviate z
+
+logp <- function(z) log(2) + pnorm(-abs(z), lower.tail = TRUE, log.p = TRUE)
+
+# log10(p) for a normal deviate z
 
 log10p <- function(z)
   log(2, base=10)+pnorm(-abs(z), lower.tail=TRUE, log.p=TRUE)/log(10)
@@ -544,6 +548,9 @@ gc.lambda <- function(p) {
   return(lambda)
 }
 
+lambda1000 <- function(lambda, ncases, ncontrols)
+  1 + (lambda - 1) * (1 / ncases + 1 / ncontrols)/( 1 / 1000 + 1 / 1000)
+
 miamiplot <- function (x, chr = "CHR", bp = "BP", p = "P", pr = "PR", snp = "SNP", 
     col = c("midnightblue", "chartreuse4"), col2 = c("royalblue1", 
         "seagreen1"), ymax = NULL, highlight = NULL, highlight.add = NULL, 
@@ -854,3 +861,136 @@ circos.mhtplot <- function(data, glist)
   circlize::circos.genomicLabels(ann, labels.column = 4, side = "inside")
   circlize::circos.clear()
 }
+
+# credible set
+
+cs <- function(tbl, b="Effect", se="StdErr", log_p=NULL, cutoff=0.95)
+{
+  z1 <- function(z) max(abs(z), na.rm = TRUE)
+  requireNamespace("matrixStats")
+  u <- tbl
+  tbl <- within(u, {
+    if (is.null(log_p)) z <- u[[b]]/u[[se]]
+    else z <- qnorm(u[[log_p]], log.p=TRUE)
+    m <- z1(z)
+    z2 <- z * z / 2
+    d <- matrixStats::logSumExp(z2)
+    log_ppa <- z2 - d
+    ppa <- exp(log_ppa)
+    cat("denominator = ", d, ", scaling factor = exp(",m, "^2/2)\n",sep="")
+  })
+  ord <- with(tbl, order(-ppa))
+  tbl <- within(tbl[ord,], {cppa <- cumsum(ppa)})
+  tbl[which(with(tbl,cppa) >= cutoff)[1],]
+}
+
+xy <- function(x) if (x<23) x else if (x==23) "X" else if (x==24) "Y"
+
+ixy <- function(x) if (x=="X") 23 else if (x=="Y") 24 else x
+
+hg38 <- c(248956422,242193529,198295559,190214555,181538259,170805979,159345973,145138636,138394717,133797422,135086622,133275309,
+          114364328,107043718,101991189,90338345,83257441,80373285,58617616,64444167,46709983,50818468,156040895,57227415)
+hg19 <- c(249250621,243199373,198022430,191154276,180915260,171115067,159138663,146364022,141213431,135534747,135006516,133851895,
+          115169878,107349540,102531392,90354753,81195210,78077248,59128983,63025520,48129895,51304566,155270560,59373566)
+hg18 <- c(247249719,242951149,199501827,191273063,180857866,170899992,158821424,146274826,140273252,135374737,134452384,132349534,
+          114142980,106368585,100338915,88827254,78774742,76117153,63811651,62435964,46944323,49691432,154913754,57772954)
+
+grid2d <- function(chrlen=hg19, cex=0.6)
+{
+  CM <- cumsum(chrlen)
+  n <- length(chrlen)
+  par(xaxt = "n", yaxt = "n")
+  xy <- xy.coords(c(0,CM), c(0,CM))
+  plot(xy$x, xy$y, type = "n", ann = FALSE, axes = FALSE)
+  par(xaxt = "s", yaxt = "s", xpd = TRUE)
+  for (x in 1:n) {
+      segments(CM[x],0,CM[x],CM[n],col="black")
+      segments(0,CM[x],CM[n],CM[x],col="black")
+      text(ifelse(x == 1, CM[x]/2, (CM[x] + CM[x-1])/2), 0, pos = 1, offset = 0.5, xy(x), cex=cex)
+      text(0, ifelse(x == 1, CM[x]/2, (CM[x] + CM[x-1])/2), pos = 2, offset = 0.5, xy(x), cex=cex)
+  }
+  segments(0,0,CM[n],0)
+  segments(0,0,0,CM[n])
+  title(xlab="pQTL position",ylab="protein position",line=2)
+  return(list(n=n, CM=c(0,CM)))
+}
+
+mhtplot2d <- function(data, cex=0.6)
+# mhtplot2d(read.table("INF1.merge.cis.vs.trans",as.is=TRUE,header=TRUE))
+{
+  r <- grid2d()
+  n <- with(r, n)
+  CM <- with(r, CM)
+  d <- data[c("Chr","bp","p.chr","p.start","p.end","log10p","cis")]
+  chr1 <- d[["Chr"]]
+  chr1[chr1=="X"] <- 23
+  chr1[chr1=="Y"] <- 24
+  pos1 <- CM[chr1] + d[["bp"]]
+  chr2 <- d[["p.chr"]]
+  chr2[chr2=="X"] <- 23
+  chr2[chr2=="Y"] <- 24
+  pos2 <- CM[chr2] + (d[["p.start"]] + d[["p.end"]])/2
+  points(pos1,pos2,cex=cex,col=ifelse(d[["cis"]],"red","blue"),pch=19)
+  legend("top",legend=c("cis","trans"),box.lty=0,cex=cex,col=c("red","blue"),horiz=TRUE,inset=c(0,1),xpd=TRUE,pch=19)
+  return(data.frame(x=pos1,y=pos2,z=with(d,log10p),col=ifelse(d[["cis"]],"red","blue")))
+}
+
+snptest_sample <- function(data,sample_file="snptest.sample",ID_1="ID_1",ID_2="ID_2",missing="missing",C=NULL,D=NULL,P=NULL)
+{
+  cat(ID_1,ID_2,missing,C,D,P,file=sample_file)
+  cat("\n",file=sample_file,append=TRUE)
+  len_C <- length(C)
+  len_D <- length(D)
+  len_P <- length(P)
+  cat("0 0 0",rep("C",len_C),rep("D",len_D),rep("P",len_P),file=sample_file,append=TRUE)
+  cat("\n",file=sample_file,append=TRUE)
+  write.table(data[c(ID_1,ID_2,missing,C,D,P)],file=sample_file,append=TRUE,row.names=FALSE,col.names=FALSE,quote=FALSE)
+}
+
+chr_pos_a1_a2 <- function(chr,pos,a1,a2,prefix="chr",seps=c(":","_","_"),uppercase=TRUE)
+{
+  chr <- paste0(prefix,chr)
+  chrpos <- paste(chr,pos,sep=seps[1])
+  a1a2 <- vector("character",length(pos))
+  index <- (a1 < a2)
+  a1a2[index] <- paste(a1,a2,sep=seps[3])[index]
+  a1a2[!index] <- paste(a2,a1,sep=seps[3])[!index]
+  a1a2 <- ifelse(uppercase,toupper(a1a2),tolower(a1a2))
+  return (paste(chrpos,a1a2,sep=seps[2]))
+}
+
+inv_chr_pos_a1_a2 <- function(chr_pos_a1_a2,prefix="chr",seps=c(":","_","_"))
+{
+  if ((seps[1]==seps[2])&(seps[2]==seps[3]))
+  {
+    s <- sapply(chr_pos_a1_a2,strsplit,seps[1])
+    chr <- lapply(s,"[",1)
+    pos <- lapply(s,"[",2)
+    a1 <- lapply(s,"[",3)
+    a2 <- lapply(s,"[",4)
+  } else if ((seps[1]!=seps[2])&(seps[2]==seps[3]))
+  {
+    s <- sapply(chr_pos_a1_a2,strsplit,seps[2])
+    chrpos <- lapply(s,"[",1)
+    s1 <- sapply(chrpos,strsplit,seps[1])
+    chr <- lapply(s1,"[",1)
+    pos <- lapply(s1,"[",2)
+    a1 <- lapply(s,"[",2)
+    a2 <- lapply(s,"[",3)
+  } else if ((seps[1]!=seps[2])&(seps[2]!=seps[3]))
+  {
+    s <- sapply(chr_pos_a1_a2,strsplit,seps[2])
+    chrpos <- lapply(s,"[",1)
+    s1 <- sapply(chrpos,strsplit,seps[1])
+    chr <- lapply(s1,"[",1)
+    pos <- lapply(s1,"[",2)
+    s2 <- lapply(s,"[",2)
+    s3 <- sapply(s2,strsplit,seps[3])
+    a1 <- lapply(s3,"[",1)
+    a2 <- lapply(s3,"[",2)
+  }
+  if (prefix=="") chr <- gsub("chr","",chr)
+  s <- data.frame(chr=unlist(chr),pos=unlist(pos),a1=unlist(a1),a2=unlist(a2))
+  names(s) <- c("chr","pos","a1","a2")
+  return(s)
+}
